==> ec2-0.33.0-sources.jar: software/amazon/awscdk/services/ec2/InstanceTypePair.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Instance type for EC2 instances.
 * 
 * This class takes a combination of a class and size.
 * 
 * Be aware that not all combinations of class and size are available, and not all
 * classes are available in all regions.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.0 (build 3d6415e)", date = "2019-05-30T15:03:30.395Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.InstanceTypePair")
public class InstanceTypePair extends software.amazon.awscdk.services.ec2.InstanceType {
    protected InstanceTypePair(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    public InstanceTypePair(final software.amazon.awscdk.services.ec2.InstanceClass instanceClass, final software.amazon.awscdk.services.ec2.InstanceSize instanceSize) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(instanceClass, "instanceClass is required"), java.util.Objects.requireNonNull(instanceSize, "instanceSize is required") });
    }

    public software.amazon.awscdk.services.ec2.InstanceClass getInstanceClass() {
        return this.jsiiGet("instanceClass", software.amazon.awscdk.services.ec2.InstanceClass.class);
    }

    public software.amazon.awscdk.services.ec2.InstanceSize getInstanceSize() {
        return this.jsiiGet("instanceSize", software.amazon.awscdk.services.ec2.InstanceSize.class);
    }
}

==> ec2-0.34.0-sources.jar: software/amazon/awscdk/services/ec2/InstanceTypePair.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Instance type for EC2 instances.
 * 
 * This class takes a combination of a class and size.
 * 
 * Be aware that not all combinations of class and size are available, and not all
 * classes are available in all regions.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.11.2 (build 27d16c2)", date = "2019-06-10T11:04:59.490Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.InstanceTypePair")
public class InstanceTypePair extends software.amazon.awscdk.services.ec2.InstanceType {
    protected InstanceTypePair(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public InstanceTypePair(final software.amazon.awscdk.services.ec2.InstanceClass instanceClass, final software.amazon.awscdk.services.ec2.InstanceSize instanceSize) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(instanceClass, "instanceClass is required"), java.util.Objects.requireNonNull(instanceSize, "instanceSize is required") });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.ec2.InstanceClass getInstanceClass() {
        return this.jsiiGet("instanceClass", software.amazon.awscdk.services.ec2.InstanceClass.class);
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public software.amazon.awscdk.services.ec2.InstanceSize getInstanceSize() {
        return this.jsiiGet("instanceSize", software.amazon.awscdk.services.ec2.InstanceSize.class);
    }
}
